"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatPrice = void 0;
var react_1 = require("react");
var commerce_1 = require("./commerce");
function formatPrice(_a) {
    var amount = _a.amount, currencyCode = _a.currencyCode, locale = _a.locale;
    var formatCurrency = new Intl.NumberFormat(locale, {
        style: 'currency',
        currency: currencyCode
    });
    return formatCurrency.format(amount);
}
exports.formatPrice = formatPrice;
function usePrice(data) {
    var currencyCode = commerce_1.useCommerce().currencyCode;
    var _a = data !== null && data !== void 0 ? data : {}, amount = _a.amount, variant = _a.variant;
    var locale = 'en-US';
    var variantPriceInCurrency = -1;
    if (variant && variant.presentmentPrices) {
        var pricePresentmentInCurrency = variant.presentmentPrices.find(function (presentmentPrice) {
            return presentmentPrice.price.currencyCode === currencyCode;
        });
        if (pricePresentmentInCurrency) {
            variantPriceInCurrency = pricePresentmentInCurrency.price.amount;
        }
    }
    var amountToUse = amount || variantPriceInCurrency;
    // best to return empty string than an incorrect value
    if (amountToUse < 0) {
        return { price: '' };
    }
    var value = react_1.useMemo(function () {
        return formatPrice({ amount: amountToUse, currencyCode: currencyCode, locale: locale });
    }, [amount, currencyCode]);
    return { price: value };
}
exports.default = usePrice;
